@@ -21,6 +21,8 @@ if is_ssl:
 class ExceptionRecursiveRet(Exception):
     pass
 
+class AuthenticationFailedException(Exception):
+    pass
 
 class ExceptionCodeRet(Exception):
     pass
@@ -365,19 +367,19 @@ class GSQL_Client(object):
     def login(self,commit_try="",version_try=""):
         
         if self._client_commit == "" and commit_try == "":
-            print('\033[33m' + "======= NO Version defined ============")
+            # print('\033[33m' + "======= NO Version defined ============")
             
             for k in VERSION_COMMIT:
-                print( '\033[33m' + "==== Trying Version : {}".format(k))
+                # print( '\033[33m' + "==== Trying Version : {}".format(k))
 
                 if(self.login(version_try=k,commit_try=VERSION_COMMIT[k]) == True):
-                    print('\x1b[6;30;42m' + "Succeded ! your version is {}".format(k) + '\x1b[0m')
+                    # print('\x1b[6;30;42m' + "Succeded ! your version is {}".format(k) + '\x1b[0m')
                     
                     break
                 else:
                     CRED = '\033[91m'
                     CEND = '\033[0m'
-                    print(CRED + "Failed to connect version <> {}".format(k) + CEND)
+                    # print(CRED + "Failed to connect version <> {}".format(k) + CEND)
                     
                 import time
                 time.sleep(2)
@@ -401,7 +403,7 @@ class GSQL_Client(object):
 
                 compatible = res.get("isClientCompatible", True)
                 if not compatible:
-                    print("This client is not compatible with target TigerGraph Server!  Please specify a correct version when creating this client!")
+                    # print("This client is not compatible with target TigerGraph Server!  Please specify a correct version when creating this client!")
                     return False
 
 
